@@ -1,6 +1,5 @@
-
 package ZooZ::Callbacks;
-$ZooZ::Callbacks::VERSION = '1.9.2';
+
 # this package takes care of registering and keeping
 # track of callbacks. Ideally, only one callback object
 # needs to be created per project which contains all
@@ -8,6 +7,7 @@ $ZooZ::Callbacks::VERSION = '1.9.2';
 # By callbacks, I really mean subroutines.
 
 use strict;
+use warnings;
 use base qw/ZooZ::Base/;
 
 my %CODE2NAME;    # hash to associate CODE(0xFFFF) with its sub name.
@@ -72,30 +72,3 @@ sub name2code {
 }
 
 sub code2name { $CODE2NAME{$_[1]} }
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-ZooZ::Callbacks
-
-=head1 VERSION
-
-version 1.9.2
-
-=head1 AUTHOR
-
-Ala Qumsieh, faraco <skelic3@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2004-2005, 2018 by Ala Qumsieh, faraco.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
