@@ -1,7 +1,7 @@
-
 package ZooZ::DefaultArgs;
-$ZooZ::DefaultArgs::VERSION = '1.9.2';
+
 use strict;
+use warnings;
 
 our %defaultWidgetArgs = (
 			  'Image' => sub {
@@ -59,30 +59,3 @@ sub getDefaultPlacementArgs {
   return exists $defaultPlacementArgs{$w} ?
     $defaultPlacementArgs{$w} : {};
 }
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-ZooZ::DefaultArgs
-
-=head1 VERSION
-
-version 1.9.2
-
-=head1 AUTHOR
-
-Ala Qumsieh, faraco <skelic3@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2004-2005, 2018 by Ala Qumsieh, faraco.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
