@@ -1,6 +1,5 @@
-
 package ZooZ::Forms;
-$ZooZ::Forms::VERSION = '1.9.2';
+
 #
 # This package implements all the forms for ZooZ.
 # These include:
@@ -11,6 +10,7 @@ $ZooZ::Forms::VERSION = '1.9.2';
 # 5. choose variable form.
 
 use strict;
+use warnings;
 use Storable;  # remove an error from Tk::CodeText
 
 use ZooZ::Fonts;
@@ -1164,7 +1164,7 @@ sub configureWidget {
 
       # Handle special tabs for special widgets.
       # For notebooks, add tab to add/delete pages.
-      if (main::NOTEBOOK_SUPPORT && ref($widget) eq 'Tk::NoteBook') {
+      if ($main::NOTEBOOK_SUPPORT && ref($widget) eq 'Tk::NoteBook') {
 	# add one tab.
 	# A notebook is allowed to have at least one tab.
 	my $defaultTabName  = 'Tab1';
@@ -1320,7 +1320,7 @@ sub configureWidget {
 			   );
 
 	# Check if we have menu builder support enabled.
-      } elsif (main::MENU_BUILDER_SUPPORT && ref($widget) eq 'Tk::Toplevel') {
+      } elsif ($main::MENU_BUILDER_SUPPORT && ref($widget) eq 'Tk::Toplevel') {
 	$MENUS[$projid]{ENABLED} = 0;
 
 	my $lf;
@@ -1780,30 +1780,3 @@ sub configureRowCol {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-ZooZ::Forms
-
-=head1 VERSION
-
-version 1.9.2
-
-=head1 AUTHOR
-
-Ala Qumsieh, faraco <skelic3@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2004-2005, 2018 by Ala Qumsieh, faraco.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
