@@ -1,8 +1,9 @@
 package ZooZ::Generic;
-$ZooZ::Generic::VERSION = '1.9.2';
+
 # this defines some generic functions that can be used by anyone.
 
 use strict;
+use warnings;
 
 sub BindMouseWheel {
   my ($top, $w) = @_;
@@ -299,30 +300,3 @@ sub lineUpCommas {
 }
 
 'the truth';
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-ZooZ::Generic
-
-=head1 VERSION
-
-version 1.9.2
-
-=head1 AUTHOR
-
-Ala Qumsieh, faraco <skelic3@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2004-2005, 2018 by Ala Qumsieh, faraco.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
