@@ -1,6 +1,6 @@
-
 package ZooZ::Options;
-$ZooZ::Options::VERSION = '1.9.2';
+
+use warnings;
 use strict;
 use Tk;
 use Tk::BrowseEntry;
@@ -425,29 +425,3 @@ sub _chooseColor {
 
 1;
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-ZooZ::Options
-
-=head1 VERSION
-
-version 1.9.2
-
-=head1 AUTHOR
-
-Ala Qumsieh, faraco <skelic3@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2004-2005, 2018 by Ala Qumsieh, faraco.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
