@@ -1,7 +1,7 @@
-
 package ZooZ::TiedVar;
-$ZooZ::TiedVar::VERSION = '1.9.2';
+
 use strict;
+use warnings;
 
 # The purpose of this is to automatically apply
 # any changes to widget options as soon as those
@@ -52,30 +52,3 @@ sub STORE {
 }
 
 sub changed { $_[0]{C} }
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-ZooZ::TiedVar
-
-=head1 VERSION
-
-version 1.9.2
-
-=head1 AUTHOR
-
-Ala Qumsieh, faraco <skelic3@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2004-2005, 2018 by Ala Qumsieh, faraco.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
