@@ -1,12 +1,12 @@
-
 package ZooZ::varRefs;
-$ZooZ::varRefs::VERSION = '1.9.2';
+
 # this package takes care of registering and keeping
 # track of variables. Ideally, only one varRef object
 # needs to be created per project which contains all
 # the information of all registered variables.
 
 use strict;
+use warnings;
 
 my %REF2NAME;
 
@@ -58,30 +58,3 @@ sub name2ref {
 sub ref2name { $REF2NAME{$_[1]} }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-ZooZ::varRefs
-
-=head1 VERSION
-
-version 1.9.2
-
-=head1 AUTHOR
-
-Ala Qumsieh, faraco <skelic3@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2004-2005, 2018 by Ala Qumsieh, faraco.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
